==> grib2io-2.0.0rc2.tar.gz: grib2io-2.0.0rc2/grib2io/tables/section4_discipline10.py <==
table_4_2_10_0  = {
'0':['Wave Spectra (1)','-','WVSP1'],
'1':['Wave Spectra (2)','-','WVSP2'],
'2':['Wave Spectra (3)','-','WVSP3'],
'3':['Significant Height of Combined Wind Waves and Swell','m','HTSGW'],
'4':['Direction of Wind Waves','degree true','WVDIR'],
'5':['Significant Height of Wind Waves','m','WVHGT'],
'6':['Mean Period of Wind Waves','s','WVPER'],
'7':['Direction of Swell Waves','degree true','SWDIR'],
'8':['Significant Height of Swell Waves','m','SWELL'],
'9':['Mean Period of Swell Waves','s','SWPER'],
'10':['Primary Wave Direction','degree true','DIRPW'],
'11':['Primary Wave Mean Period','s','PERPW'],
'12':['Secondary Wave Direction','degree true','DIRSW'],
'13':['Secondary Wave Mean Period','s','PERSW'],
'14':['Direction of Combined Wind Waves and Swell','degree true','WWSDIR'],
'15':['Mean Period of Combined Wind Waves and Swell','s','MWSPER'],
'16':['Coefficient of Drag With Waves','-','CDWW'],
'17':['Friction Velocity','m s-1','FRICVW'],
'18':['Wave Stress','N m-2','WSTR'],
'19':['Normalised Waves Stress','-','NWSTR'],
'20':['Mean Square Slope of Waves','-','MSSW'],
'21':['U-component Surface Stokes Drift','m s-1','USSD'],
'22':['V-component Surface Stokes Drift','m s-1','VSSD'],
'23':['Period of Maximum Individual Wave Height','s','PMAXWH'],
'24':['Maximum Individual Wave Height','m','MAXWH'],
'25':['Inverse Mean Wave Frequency','s','IMWF'],
'26':['Inverse Mean Frequency of The Wind Waves','s','IMFWW'],
'27':['Inverse Mean Frequency of The Total Swell','s','IMFTSW'],
'28':['Mean Zero-Crossing Wave Period','s','MZWPER'],
'29':['Mean Zero-Crossing Period of The Wind Waves','s','MZPWW'],
'30':['Mean Zero-Crossing Period of The Total Swell','s','MZPTSW'],
'31':['Wave Directional Width','-','WDIRW'],
'32':['Directional Width of The Wind Waves','-','DIRWWW'],
'33':['Directional Width of The Total Swell','-','DIRWTS'],
'34':['Peak Wave Period','s','PWPER'],
'35':['Peak Period of The Wind Waves','s','PPERWW'],
'36':['Peak Period of The Total Swell','s','PPERTS'],
'37':['Altimeter Wave Height','m','ALTWH'],
'38':['Altimeter Corrected Wave Height','m','ALCWH'],
'39':['Altimeter Range Relative Correction','-','ALRRC'],
'40':['10 Metre Neutral Wind Speed Over Waves','m s-1','MNWSOW'],
'41':['10 Metre Wind Direction Over Waves','degree true','MWDIRW'],
'42':['Wave Engery Spectrum','m-2 s rad-1','WESP'],
'43':['Kurtosis of The Sea Surface Elevation Due to Waves','-','KSSEW'],
'44':['Benjamin-Feir Index','-','BENINX'],
'45':['Spectral Peakedness Factor','s-1','SPFTR'],
'46':['Peak wave direction','&deg','PWAVEDIR'],
'47':['Significant wave height of first swell partition','m','SWHFSWEL'],
'48':['Significant wave height of second swell partition','m','SWHSSWEL'],
'49':['Significant wave height of third swell partition','m','SWHTSWEL'],
'50':['Mean wave period of first swell partition','s','MWPFSWEL'],
'51':['Mean wave period of second swell partition','s','MWPSSWEL'],
'52':['Mean wave period of third swell partition','s','MWPTSWEL'],
'53':['Mean wave direction of first swell partition','&deg','MWDFSWEL'],
'54':['Mean wave direction of second swell partition','&deg','MWDSSWEL'],
'55':['Mean wave direction of third swell partition','&deg','MWDTSWEL'],
'56':['Wave directional width of first swell partition','-','WDWFSWEL'],
'57':['Wave directional width of second swell partition','-','WDWSSWEL'],
'58':['Wave directional width of third swell partition','-','WDWTSWEL'],
'59':['Wave frequency width of first swell partition','-','WFWFSWEL'],
'60':['Wave frequency width of second swell partition','-','WFWSSWEL'],
'61':['Wave frequency width of third swell partition','-','WFWTSWEL'],
'62':['Wave frequency width','-','WAVEFREW'],
'63':['Frequency width of wind waves','-','FREWWW'],
'64':['Frequency width of total swell','-','FREWTSW'],
'65':['Peak Wave Period of First Swell Partition','s','PWPFSPAR'],
'66':['Peak Wave Period of Second Swell Partition','s','PWPSSPAR'],
'67':['Peak Wave Period of Third Swell Partition','s','PWPTSPAR'],
'68':['Peak Wave Direction of First Swell Partition','degree true','PWDFSPAR'],
'69':['Peak Wave Direction of Second Swell Partition','degree true','PWDFSPAR'],
'70':['Peak Wave Direction of First Swell Partition','degree true','PWDSSPAR'],
'71':['Peak Direction of Wind Waves','degree true','PDWWAVE'],
'72':['Peak Direction of Total Swell','degree true','PDTSWELL'],
'73':['Whitecap Fraction','fraction','WCAPFRAC'],
'74-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Wave Steepness','proportion','WSTP'],
'193':['Wave Length','unknown','WLENG'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_1  = {
'0':['Current Direction','degree True','DIRC'],
'1':['Current Speed','m s-1','SPC'],
'2':['U-Component of Current','m s-1','UOGRD'],
'3':['V-Component of Current','m s-1','VOGRD'],
'4':['Rip Current Occurrence Probability','%','RIPCOP'],
'5-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Ocean Mixed Layer U Velocity','m s-1','OMLU'],
'193':['Ocean Mixed Layer V Velocity','m s-1','OMLV'],
'194':['Barotropic U velocity','m s-1','UBARO'],
'195':['Barotropic V velocity','m s-1','VBARO'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_2  = {
'0':['Ice Cover','Proportion','ICEC'],
'1':['Ice Thickness','m','ICETK'],
'2':['Direction of Ice Drift','degree True','DICED'],
'3':['Speed of Ice Drift','m s-1','SICED'],
'4':['U-Component of Ice Drift','m s-1','UICE'],
'5':['V-Component of Ice Drift','m s-1','VICE'],
'6':['Ice Growth Rate','m s-1','ICEG'],
'7':['Ice Divergence','s-1','ICED'],
'8':['Ice Temperature','K','ICETMP'],
'9':['Module of Ice Internal Pressure','Pa m','ICEPRS'],
'10':['Zonal Vector Component of Vertically Integrated Ice Internal Pressure','Pa m','ZVCICEP'],
'11':['Meridional Vector Component of Vertically Integrated Ice Internal Pressure','Pa m','MVCICEP'],
'12':['Compressive Ice Strength','N m-1','CICES'],
'13':['Snow Temperature (over sea ice)','K','SNOWTSI'],
'14':['Albedo','Numeric','ALBICE'],
'15-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_3  = {
'0':['Water Temperature','K','WTMP'],
'1':['Deviation of Sea Level from Mean','m','DSLM'],
'2':['Heat Exchange Coefficient','unknown','CH'],
'3':['Practical Salinity','Numeric','PRACTSAL'],
'4':['Downward Heat Flux','W m-2','DWHFLUX'],
'5':['Eastward Surface Stress','W m-2','EASTWSS'],
'6':['Northward surface stress','W m-2','NORTHWSS'],
'7':['X-component Surface Stress','W m-2','XCOMPSS'],
'8':['Y-component Surface Stress','W m-2','YCOMPSS'],
'9':['Thermosteric Change in Sea Surface Height','m','THERCSSH'],
'10':['Halosteric Change in Sea Surface Height','m','HALOCSSH'],
'11':['Steric Change in Sea Surface Height','m','STERCSSH'],
'12':['Sea Salt Flux','kg m-2s-1','SEASFLUX'],
'13-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Hurricane Storm Surge','m','SURGE'],
'193':['Extra Tropical Storm Surge','m','ETSRG'],
'194':['Ocean Surface Elevation Relative to Geoid','m','ELEV'],
'195':['Sea Surface Height Relative to Geoid','m','SSHG'],
'196':['Ocean Mixed Layer Potential Density (Reference 2000m)','kg m-3','P2OMLT'],
'197':['Net Air-Ocean Heat Flux','W m-2','AOHFLX'],
'198':['Assimilative Heat Flux','W m-2','ASHFL'],
'199':['Surface Temperature Trend','degree per day','SSTT'],
'200':['Surface Salinity Trend','psu per day','SSST'],
'201':['Kinetic Energy','J kg-1','KENG'],
'202':['Salt Flux','kg m-2s-1','SLTFL'],
'203':['Heat Exchange Coefficient','unknown','LCH'],
'204':['Freezing Spray','unknown','FRZSPR'],
'205':['Total Water Level Accounting for Tide, Wind and Waves','m','TWLWAV'],
'206':['Total Water Level Increase due to Waves','m','RUNUP'],
'207':['Mean Increase in Water Level due to Waves','m','SETUP'],
'208':['Time-varying Increase in Water Level due to Waves','m','SWASH'],
'209':['Total Water Level Above Dune Toe','m','TWLDT'],
'210':['Total Water Level Above Dune Crest','m','TWLDC'],
'211-241':['Reserved','unknown','unknown'],
'242':['20% Tropical Cyclone Storm Surge Exceedance','m','TCSRG20'],
'243':['30% Tropical Cyclone Storm Surge Exceedance','m','TCSRG30'],
'244':['40% Tropical Cyclone Storm Surge Exceedance','m','TCSRG40'],
'245':['50% Tropical Cyclone Storm Surge Exceedance','m','TCSRG50'],
'246':['60% Tropical Cyclone Storm Surge Exceedance','m','TCSRG60'],
'247':['70% Tropical Cyclone Storm Surge Exceedance','m','TCSRG70'],
'248':['80% Tropical Cyclone Storm Surge Exceedance','m','TCSRG80'],
'249':['90% Tropical Cyclone Storm Surge Exceedance','m','TCSRG90'],
'250':['Extra Tropical Storm Surge Combined Surge and Tide','m','ETCWL'],
'251':['Tide','m','TIDE'],
'252':['Erosion Occurrence Probability','%','EROSNP'],
'253':['Overwash Occurrence Probability','%','OWASHP'],
'254':['Reserved','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_4  = {
'0':['Main Thermocline Depth','m','MTHD'],
'1':['Main Thermocline Anomaly','m','MTHA'],
'2':['Transient Thermocline Depth','m','TTHDP'],
'3':['Salinity','kg kg-1','SALTY'],
'4':['Ocean Vertical Heat Diffusivity','m2 s-1','OVHD'],
'5':['Ocean Vertical Salt Diffusivity','m2 s-1','OVSD'],
'6':['Ocean Vertical Momentum Diffusivity','m2 s-1','OVMD'],
'7':['Bathymetry','m','BATHY'],
'8-10':['Reserved','unknown','unknown'],
'11':['Shape Factor With Respect To Salinity Profile','unknown','SFSALP'],
'12':['Shape Factor With Respect To Temperature Profile In Thermocline','unknown','SFTMPP'],
'13':['Attenuation Coefficient Of Water With Respect to Solar Radiation','m-1','ACWSRD'],
'14':['Water Depth','m','WDEPTH'],
'15':['Water Temperature','K','WTMPSS'],
'16':['Water Density (rho)','kg m-3','WATERDEN'],
'17':['Water Density Anomaly (sigma) See note','kg m-3','WATDENA'],
'18':['Water potential temperature (theta)','K','WATPTEMP'],
'19':['Water potential density (rho theta)','kg m-3','WATPDEN'],
'20':['Water potential density anomaly (sigma theta) See Note','kg m-3','WATPDENA'],
'21':['Practical Salinity','psu (numeric)','PRTSAL'],
'22':['Water Column-integrated Heat Content','J m-2','WCHEATC'],
'23':['Eastward Water Velocity','m s-1','EASTWVEL'],
'24':['Northward Water Velocity','m s-1','NRTHWVEL'],
'25':['X-Component Water Velocity','m s-1','XCOMPWV'],
'26':['Y-Component Water Velocity','m s-1','YCOMPWV'],
'27':['Upward Water Velocity','m s-1','UPWWVEL'],
'28':['Vertical Eddy Diffusivity','m2 s-1','VEDDYDIF'],
'29-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['3-D Temperature','° c','WTMPC'],
'193':['3-D Salinity','psu','SALIN'],
'194':['Barotropic Kinectic Energy','J kg-1','BKENG'],
'195':['Geometric Depth Below Sea Surface','m','DBSS'],
'196':['Interface Depths','m','INTFD'],
'197':['Ocean Heat Content','J m-2','OHC'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_191  = {
'0':['Seconds Prior To Initial Reference Time (Defined In Section 1)','s','IRTSEC'],
'1':['Meridional Overturning Stream Function','m3 s-1','MOSF'],
'2':['Reserved','unknown','unknown'],
'3':['Days Since Last Observation','d','DSLOBS'],
'4':['Barotropic Stream Function','m3 s-1','BARDSF'],
'5-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}

==> grib2io-2.0.1.tar.gz: grib2io-2.0.1/grib2io/tables/section4_discipline10.py <==
table_4_2_10_0  = {
'0':['Wave Spectra (1)','-','WVSP1'],
'1':['Wave Spectra (2)','-','WVSP2'],
'2':['Wave Spectra (3)','-','WVSP3'],
'3':['Significant Height of Combined Wind Waves and Swell','m','HTSGW'],
'4':['Direction of Wind Waves','degree true','WVDIR'],
'5':['Significant Height of Wind Waves','m','WVHGT'],
'6':['Mean Period of Wind Waves','s','WVPER'],
'7':['Direction of Swell Waves','degree true','SWDIR'],
'8':['Significant Height of Swell Waves','m','SWELL'],
'9':['Mean Period of Swell Waves','s','SWPER'],
'10':['Primary Wave Direction','degree true','DIRPW'],
'11':['Primary Wave Mean Period','s','PERPW'],
'12':['Secondary Wave Direction','degree true','DIRSW'],
'13':['Secondary Wave Mean Period','s','PERSW'],
'14':['Direction of Combined Wind Waves and Swell','degree true','WWSDIR'],
'15':['Mean Period of Combined Wind Waves and Swell','s','MWSPER'],
'16':['Coefficient of Drag With Waves','-','CDWW'],
'17':['Friction Velocity','m s-1','FRICVW'],
'18':['Wave Stress','N m-2','WSTR'],
'19':['Normalised Waves Stress','-','NWSTR'],
'20':['Mean Square Slope of Waves','-','MSSW'],
'21':['U-component Surface Stokes Drift','m s-1','USSD'],
'22':['V-component Surface Stokes Drift','m s-1','VSSD'],
'23':['Period of Maximum Individual Wave Height','s','PMAXWH'],
'24':['Maximum Individual Wave Height','m','MAXWH'],
'25':['Inverse Mean Wave Frequency','s','IMWF'],
'26':['Inverse Mean Frequency of The Wind Waves','s','IMFWW'],
'27':['Inverse Mean Frequency of The Total Swell','s','IMFTSW'],
'28':['Mean Zero-Crossing Wave Period','s','MZWPER'],
'29':['Mean Zero-Crossing Period of The Wind Waves','s','MZPWW'],
'30':['Mean Zero-Crossing Period of The Total Swell','s','MZPTSW'],
'31':['Wave Directional Width','-','WDIRW'],
'32':['Directional Width of The Wind Waves','-','DIRWWW'],
'33':['Directional Width of The Total Swell','-','DIRWTS'],
'34':['Peak Wave Period','s','PWPER'],
'35':['Peak Period of The Wind Waves','s','PPERWW'],
'36':['Peak Period of The Total Swell','s','PPERTS'],
'37':['Altimeter Wave Height','m','ALTWH'],
'38':['Altimeter Corrected Wave Height','m','ALCWH'],
'39':['Altimeter Range Relative Correction','-','ALRRC'],
'40':['10 Metre Neutral Wind Speed Over Waves','m s-1','MNWSOW'],
'41':['10 Metre Wind Direction Over Waves','degree true','MWDIRW'],
'42':['Wave Engery Spectrum','m-2 s rad-1','WESP'],
'43':['Kurtosis of The Sea Surface Elevation Due to Waves','-','KSSEW'],
'44':['Benjamin-Feir Index','-','BENINX'],
'45':['Spectral Peakedness Factor','s-1','SPFTR'],
'46':['Peak wave direction','&deg','PWAVEDIR'],
'47':['Significant wave height of first swell partition','m','SWHFSWEL'],
'48':['Significant wave height of second swell partition','m','SWHSSWEL'],
'49':['Significant wave height of third swell partition','m','SWHTSWEL'],
'50':['Mean wave period of first swell partition','s','MWPFSWEL'],
'51':['Mean wave period of second swell partition','s','MWPSSWEL'],
'52':['Mean wave period of third swell partition','s','MWPTSWEL'],
'53':['Mean wave direction of first swell partition','&deg','MWDFSWEL'],
'54':['Mean wave direction of second swell partition','&deg','MWDSSWEL'],
'55':['Mean wave direction of third swell partition','&deg','MWDTSWEL'],
'56':['Wave directional width of first swell partition','-','WDWFSWEL'],
'57':['Wave directional width of second swell partition','-','WDWSSWEL'],
'58':['Wave directional width of third swell partition','-','WDWTSWEL'],
'59':['Wave frequency width of first swell partition','-','WFWFSWEL'],
'60':['Wave frequency width of second swell partition','-','WFWSSWEL'],
'61':['Wave frequency width of third swell partition','-','WFWTSWEL'],
'62':['Wave frequency width','-','WAVEFREW'],
'63':['Frequency width of wind waves','-','FREWWW'],
'64':['Frequency width of total swell','-','FREWTSW'],
'65':['Peak Wave Period of First Swell Partition','s','PWPFSPAR'],
'66':['Peak Wave Period of Second Swell Partition','s','PWPSSPAR'],
'67':['Peak Wave Period of Third Swell Partition','s','PWPTSPAR'],
'68':['Peak Wave Direction of First Swell Partition','degree true','PWDFSPAR'],
'69':['Peak Wave Direction of Second Swell Partition','degree true','PWDFSPAR'],
'70':['Peak Wave Direction of First Swell Partition','degree true','PWDSSPAR'],
'71':['Peak Direction of Wind Waves','degree true','PDWWAVE'],
'72':['Peak Direction of Total Swell','degree true','PDTSWELL'],
'73':['Whitecap Fraction','fraction','WCAPFRAC'],
'74-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Wave Steepness','proportion','WSTP'],
'193':['Wave Length','unknown','WLENG'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_1  = {
'0':['Current Direction','degree True','DIRC'],
'1':['Current Speed','m s-1','SPC'],
'2':['U-Component of Current','m s-1','UOGRD'],
'3':['V-Component of Current','m s-1','VOGRD'],
'4':['Rip Current Occurrence Probability','%','RIPCOP'],
'5-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Ocean Mixed Layer U Velocity','m s-1','OMLU'],
'193':['Ocean Mixed Layer V Velocity','m s-1','OMLV'],
'194':['Barotropic U velocity','m s-1','UBARO'],
'195':['Barotropic V velocity','m s-1','VBARO'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_2  = {
'0':['Ice Cover','Proportion','ICEC'],
'1':['Ice Thickness','m','ICETK'],
'2':['Direction of Ice Drift','degree True','DICED'],
'3':['Speed of Ice Drift','m s-1','SICED'],
'4':['U-Component of Ice Drift','m s-1','UICE'],
'5':['V-Component of Ice Drift','m s-1','VICE'],
'6':['Ice Growth Rate','m s-1','ICEG'],
'7':['Ice Divergence','s-1','ICED'],
'8':['Ice Temperature','K','ICETMP'],
'9':['Module of Ice Internal Pressure','Pa m','ICEPRS'],
'10':['Zonal Vector Component of Vertically Integrated Ice Internal Pressure','Pa m','ZVCICEP'],
'11':['Meridional Vector Component of Vertically Integrated Ice Internal Pressure','Pa m','MVCICEP'],
'12':['Compressive Ice Strength','N m-1','CICES'],
'13':['Snow Temperature (over sea ice)','K','SNOWTSI'],
'14':['Albedo','Numeric','ALBICE'],
'15-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_3  = {
'0':['Water Temperature','K','WTMP'],
'1':['Deviation of Sea Level from Mean','m','DSLM'],
'2':['Heat Exchange Coefficient','unknown','CH'],
'3':['Practical Salinity','Numeric','PRACTSAL'],
'4':['Downward Heat Flux','W m-2','DWHFLUX'],
'5':['Eastward Surface Stress','N m-2','EASTWSS'],
'6':['Northward surface stress','N m-2','NORTHWSS'],
'7':['x-component Surface Stress','N m-2','XCOMPSS'],
'8':['y-component Surface Stress','N m-2','YCOMPSS'],
'9':['Thermosteric Change in Sea Surface Height','m','THERCSSH'],
'10':['Halosteric Change in Sea Surface Height','m','HALOCSSH'],
'11':['Steric Change in Sea Surface Height','m','STERCSSH'],
'12':['Sea Salt Flux','kg m-2s-1','SEASFLUX'],
'13':['Net upward water flux','kg m-2s-1','unknown'],
'14':['Eastward surface water velocity','m s-1','unknown'],
'15':['Northward surface water velocity','m s-1','unknown'],
'16':['x-component of surface water velocity','m s-1','unknown'],
'17':['y-component of surface water velocity','m s-1','unknown'],
'18':['Heat flux correction','W m-2','unknown'],
'19':['Sea surface height tendency due to parameterization','m s-1','unknown'],
'20':['Deviation of sea level from mean with inverse barometer correction','m','unknown'],
'21-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Hurricane Storm Surge','m','SURGE'],
'193':['Extra Tropical Storm Surge','m','ETSRG'],
'194':['Ocean Surface Elevation Relative to Geoid','m','ELEV'],
'195':['Sea Surface Height Relative to Geoid','m','SSHG'],
'196':['Ocean Mixed Layer Potential Density (Reference 2000m)','kg m-3','P2OMLT'],
'197':['Net Air-Ocean Heat Flux','W m-2','AOHFLX'],
'198':['Assimilative Heat Flux','W m-2','ASHFL'],
'199':['Surface Temperature Trend','degree per day','SSTT'],
'200':['Surface Salinity Trend','psu per day','SSST'],
'201':['Kinetic Energy','J kg-1','KENG'],
'202':['Salt Flux','kg m-2s-1','SLTFL'],
'203':['Heat Exchange Coefficient','unknown','LCH'],
'204':['Freezing Spray','unknown','FRZSPR'],
'205':['Total Water Level Accounting for Tide, Wind and Waves','m','TWLWAV'],
'206':['Total Water Level Increase due to Waves','m','RUNUP'],
'207':['Mean Increase in Water Level due to Waves','m','SETUP'],
'208':['Time-varying Increase in Water Level due to Waves','m','SWASH'],
'209':['Total Water Level Above Dune Toe','m','TWLDT'],
'210':['Total Water Level Above Dune Crest','m','TWLDC'],
'211-241':['Reserved','unknown','unknown'],
'242':['20% Tropical Cyclone Storm Surge Exceedance','m','TCSRG20'],
'243':['30% Tropical Cyclone Storm Surge Exceedance','m','TCSRG30'],
'244':['40% Tropical Cyclone Storm Surge Exceedance','m','TCSRG40'],
'245':['50% Tropical Cyclone Storm Surge Exceedance','m','TCSRG50'],
'246':['60% Tropical Cyclone Storm Surge Exceedance','m','TCSRG60'],
'247':['70% Tropical Cyclone Storm Surge Exceedance','m','TCSRG70'],
'248':['80% Tropical Cyclone Storm Surge Exceedance','m','TCSRG80'],
'249':['90% Tropical Cyclone Storm Surge Exceedance','m','TCSRG90'],
'250':['Extra Tropical Storm Surge Combined Surge and Tide','m','ETCWL'],
'251':['Tide','m','TIDE'],
'252':['Erosion Occurrence Probability','%','EROSNP'],
'253':['Overwash Occurrence Probability','%','OWASHP'],
'254':['Reserved','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_4  = {
'0':['Main Thermocline Depth','m','MTHD'],
'1':['Main Thermocline Anomaly','m','MTHA'],
'2':['Transient Thermocline Depth','m','TTHDP'],
'3':['Salinity','kg kg-1','SALTY'],
'4':['Ocean Vertical Heat Diffusivity','m2 s-1','OVHD'],
'5':['Ocean Vertical Salt Diffusivity','m2 s-1','OVSD'],
'6':['Ocean Vertical Momentum Diffusivity','m2 s-1','OVMD'],
'7':['Bathymetry','m','BATHY'],
'8-10':['Reserved','unknown','unknown'],
'11':['Shape Factor With Respect To Salinity Profile','unknown','SFSALP'],
'12':['Shape Factor With Respect To Temperature Profile In Thermocline','unknown','SFTMPP'],
'13':['Attenuation Coefficient Of Water With Respect to Solar Radiation','m-1','ACWSRD'],
'14':['Water Depth','m','WDEPTH'],
'15':['Water Temperature','K','WTMPSS'],
'16':['Water Density (rho)','kg m-3','WATERDEN'],
'17':['Water Density Anomaly (sigma) See note','kg m-3','WATDENA'],
'18':['Water potential temperature (theta)','K','WATPTEMP'],
'19':['Water potential density (rho theta)','kg m-3','WATPDEN'],
'20':['Water potential density anomaly (sigma theta) See Note','kg m-3','WATPDENA'],
'21':['Practical Salinity','psu (numeric)','PRTSAL'],
'22':['Water Column-integrated Heat Content','J m-2','WCHEATC'],
'23':['Eastward Water Velocity','m s-1','EASTWVEL'],
'24':['Northward Water Velocity','m s-1','NRTHWVEL'],
'25':['X-Component Water Velocity','m s-1','XCOMPWV'],
'26':['Y-Component Water Velocity','m s-1','YCOMPWV'],
'27':['Upward Water Velocity','m s-1','UPWWVEL'],
'28':['Vertical Eddy Diffusivity','m2 s-1','VEDDYDIF'],
'29-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['3-D Temperature','° c','WTMPC'],
'193':['3-D Salinity','psu','SALIN'],
'194':['Barotropic Kinectic Energy','J kg-1','BKENG'],
'195':['Geometric Depth Below Sea Surface','m','DBSS'],
'196':['Interface Depths','m','INTFD'],
'197':['Ocean Heat Content','J m-2','OHC'],
'255':['Missing','unknown','unknown'],
}
table_4_2_10_191  = {
'0':['Seconds Prior To Initial Reference Time (Defined In Section 1)','s','IRTSEC'],
'1':['Meridional Overturning Stream Function','m3 s-1','MOSF'],
'2':['Reserved','unknown','unknown'],
'3':['Days Since Last Observation','d','DSLOBS'],
'4':['Barotropic Stream Function','m3 s-1','BARDSF'],
'5-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
